<?xml version="1.0" encoding="UTF-8"?>
<!-- Document owner: Charles Hoffman, UBmatrix CharlesHoffman@olywa.net -->
<!-- FRTA Conformance Suite Testcase Stylesheet -->
<!-- Copyright 2004 XBRL International. All Rights Reserved. -->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" exclude-result-prefixes="fo">
	<xsl:template match="testcase">
		<html>
			<head>
				<title>
					<xsl:value-of select="@name"/>
				</title>
   <style>
      body {font-family:Arial;font-size:10pt;font-weight:normal;color:black;text-align:left;vertical-align:top;background-color:white;}
      h1 {font-family:Arial;font-size:14pt;font-weight:bold;color:navy;border-bottom:Navy thick solid;text-align:center;vertical-align:top;}
      .Heading {font-family:Arial;font-size:10pt;font-weight:bold;color:black;text-align:left;text-indent:-20px;padding-left:20px;}
      .SectionHeading {font-family:Arial;font-size:10pt;font-weight:normal;color:black;text-align:left;text-indent:-20px;padding-left:20px;}
      .SubSectionHeading {font-family:Arial;font-size:10pt;font-weight:bold;color:black;text-align:left;vertical-align:bottom;padding-top:15px;}
      .Label {font-family:Arial;font-size:10pt;font-weight:normal;color:black;text-align:left;text-indent:-20px;padding-left:20px;}
      .Note {font-family:Arial;font-size:10pt;font-weight:normal;color:black;text-align:right;padding-left:20px;}
      .Value {font-family:Arial;font-size:10pt;font-weight:normal;color:black;text-align:right;vertical-align:bottom;}
      .ValueLineOverUnder {font-family:Arial;font-size:10pt;font-weight:normal;color:black;text-align:right;vertical-align:bottom;border-top:black thin solid;border-bottom:black thin solid}
      .ValueLineOver {font-family:Arial;font-size:10pt;font-weight:normal;color:black;text-align:right;vertical-align:bottom;border-top:black thin solid;}
      .Blank {visibility:hidden;}
     
   </style>


			</head>
			<body>
				<table border="0">
					<tbody>
						<tr>
							<th colspan="3" align="left">
								Test name: <xsl:value-of select="@name"/>
							</th>
						</tr>
						<tr>
							<th colspan="3" align="left">
								Test ID: <xsl:value-of select="@id"/>
							</th>
						</tr>
						<!-- This is NOT APPLICABLE -->
						<xsl:if test="@minimal='false'">
							<tr>
								<td style="color:red" colspan="3" align="left">**Required for Full Conformance**</td>
							</tr>
						</xsl:if>
						<tr>
							<td colspan="3">
								Description: <xsl:value-of select="@description"/>
							</td>
						</tr>
						<tr>
							<td colspan="3">Current Owner:
								<a>
								<xsl:attribute name="href">mailto:<xsl:value-of select="@owner"/></xsl:attribute>
								<xsl:value-of select="@owner"/></a>
							</td>
						</tr>
						<tr>
							<td colspan="3"><hr style="height:3pt;color:black" /></td>
						</tr>
						<xsl:choose>
							<xsl:when test="string-length(@ignoreIf)>0">
								<tr>
									<td colspan="3">This test is ignored if <i>
											<xsl:value-of select="@ignoreIf"/>
										</i> is required by the XBRL processor being tested.</td>
								</tr>
							</xsl:when>
						</xsl:choose>
						<xsl:apply-templates select="node()"/>
					</tbody>
				</table>
			</body>
		</html>
	</xsl:template>
	<xsl:template match="variation">
		<tr>
			<td colspan="1"/>
			<td colspan="2">
				<table>
					<tbody>
						<tr>
							<th align="left">
								Variation ID: <xsl:value-of select="@id"/>
							</th>
						</tr>
						<tr>
							<th align="left">
								Variation Name: <xsl:value-of select="@name"/>
							</th>
						</tr>
						<tr>
							<th align="left">
								Variation Description: <xsl:value-of select="description"/>
							</th>
						</tr>
						<tr>
							<td>
								Files for variation:
							</td>
						</tr>
					</tbody>
				</table>
			</td>
		</tr>
		<xsl:apply-templates select="data/*"/>
		<tr>
			<td colspan="1"/>
			<td colspan="1">
				Result expected:
			</td>
			<td colspan="1">
				<xsl:value-of select="result/@expected"/>
			</td>
		</tr>
		<xsl:if test="string-length(result)>0">
			<tr>
				<td colspan="1"/>
				<td colspan="1">Result file:</td>
				<td colspan="1">
					<xsl:element name="a">
						<xsl:attribute name="href"><xsl:value-of select="../@outpath"/>/<xsl:value-of select="result"/></xsl:attribute>
						<xsl:value-of select="result"/>
					</xsl:element>
				</td>
			</tr>
		</xsl:if>
		<tr>
			<td colspan="3"><hr style="height:1pt;color:black" /></td>
		</tr>
	</xsl:template>
	<xsl:template match="xsd|linkbase|xml|instance|schema">
		<tr>
			<td/>
			<td>
				<xsl:choose>
					<xsl:when test="name()='schema'">Schema</xsl:when>
					<xsl:when test="name()='xsd'">Schema</xsl:when>
					<xsl:when test="name()='linkbase'">Linkbase</xsl:when>
					<xsl:when test="name()='xml'">Instance</xsl:when>
					<xsl:when test="name()='instance'">Instance</xsl:when>
					<xsl:otherwise>*Other</xsl:otherwise>
				</xsl:choose>:</td>
			<td>
				<xsl:element name="a">
					<xsl:attribute name="href"><xsl:value-of select="."/></xsl:attribute>
					<xsl:value-of select="."/>
				</xsl:element>
			</td>
		</tr>
	</xsl:template>
	<xsl:template match="node()"/>
</xsl:stylesheet>
